@@ -1,18 +1,29 @@
-# -*- coding: utf-8 -*-
+# Copyright 2019-2021 Davide Mancusi, Martin Maurey, Jonathan Faustin
+#
+# This file is part of t4_geom_convert.
+#
+# t4_geom_convert is free software: you can redistribute it and/or modify it
+# under the terms of the GNU General Public License as published by the Free
+# Software Foundation, either version 3 of the License, or (at your option) any
+# later version.
+#
+# t4_geom_convert is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+# more details.
+#
+# You should have received a copy of the GNU General Public License along with
+# t4_geom_convert.  If not, see <https://www.gnu.org/licenses/>.
+#
+# vim: set fileencoding=utf-8 :
+'''
+Module specifying each conversion of surface type.
 '''
 
-:author: Sogeti
-:data : 06 february 2019
-:file : DTypeConversion.py
-'''
 from .ESurfaceTypeMCNP import ESurfaceTypeMCNP as e_surfaceMCNP
 from .ESurfaceTypeT4 import ESurfaceTypeT4 as e_surfaceT4
 
 
-'''
-:brief: Python file specifying each conversion of surface type
-'''
-
 
 dict_conversionSurfaceType = dict()
 
